--[[
MinimapTarget - target units using minimap blips 

Copyright (C) 2006-2009 Adirelle

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
--]]

local Dewdrop = AceLibrary("Dewdrop-2.0")
local OldPingLocation

local targets = {}
local heap = {}

local function FeedDewdrop()
	for text, secure in pairs(targets) do
		Dewdrop:AddLine('text', text, 'secure', secure, 'closeWhenClicked', true)
	end
	Dewdrop:AddLine('text', 'Cancel', 'closeWhenClicked', true)
end

local function NewPingLocation(...)
	-- Right now, using arg1 is the only way to catch right clicks, even with SexyMap or Chinchilla in the way
	if arg1 == "RightButton" then
		if GameTooltip:IsVisible() and not InCombatLockdown() then
			local tooltipContent = GameTooltipTextLeft1:IsVisible() and GameTooltipTextLeft1:GetText()
			if tooltipContent then
				for text, t in pairs(targets) do
					heap[t] = true
					targets[text] = nil
				end
				for line in tooltipContent:gmatch("[^\n]+") do
					local text, target = line, line
					local secure = next(heap) or {}
					heap[secure] = nil
					if line:find("|c") then
						target = line:match("|c%x%x%x%x%x%x%x%x([^|]+)|r")
					end
					targets[text] = secure
					secure.type = 'macro'
					secure.macrotext = (target:find("[- ]") and "/target " or "/targetexact ")..target
				end
				if next(targets) then
					Dewdrop:Open(
						'MinimapTarget',
						'children', FeedDewdrop,
						'point', 'TOPRIGHT',
						'cursorX', -10,
						'cursorY', 10
					)
				end
			end
		end
		return -- Don't "ping" if no tooltip is shown to prevent mispings
	end
	return OldPingLocation(...)
end

local MinimapMethods = getmetatable(Minimap).__index
OldPingLocation, MinimapMethods.PingLocation = MinimapMethods.PingLocation, NewPingLocation
